# RecipeMD

A [standard format](./specification.md) for recipes as [Markdown](https://commonmark.org) files and a python reference 
implementation. The reference implementation can be used as a CLI program and as a python library.

More info on our website: [recipemd.org](https://recipemd.org)

<p>&nbsp;</p>

<a href="https://recipemd.org/"><img src="https://raw.githubusercontent.com/tstehr/RecipeMD/master/logo/recipemd-mark.png" style="float:right; margin-left:5em"></a>
